@@ -14,6 +14,7 @@ Config = {
     'SCRAPING': {
         # Whether to scrape with own ip address or just with proxies
         'use_own_ip': True,
+        'scrapemethod': 'http'
     },
     'GLOBAL': {
         # The database name, with a timestamp as fmt
@@ -45,7 +46,7 @@ Config = {
     'HTTP': {
 
     },
-    'GOOGLE_SEARCH_PARAMS': {
+    'HTTP_ASYNC': {
 
     }
 }
@@ -102,7 +103,6 @@ def parse_config(cmd_args=False):
     # and replace the global Config variable with the real thing
     Config = cfg_parser
 
-
 def parse_cmd_args(cmd_args=None):
     """Parse the command line
 
